# Copyright 1999-2014 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: /var/cvsroot/gentoo-x86/media-sound/spotify/spotify-0.9.11.27-r2.ebuild,v 1.1 2014/12/12 16:19:50 prometheanfire Exp $

EAPI=5
inherit eutils unpacker multilib gnome2-utils fdo-mime versionator

DESCRIPTION="ecoDMS client application"
HOMEPAGE="http://www.ecodms.de/"
SRC_BASE="http://www.ecodms.de/"

MY_PV=$(replace_version_separator 2 '-' )
MY_P="${PN}-${MY_PV}"
EDITION=$(delete_all_version_separators $(get_version_component_range 1-2 ${MY_PV} ))
SRC_URI="
        amd64? ( ${SRC_BASE}ecodms_${EDITION}64/wheezy/${MY_P}_amd64.deb )
        x86?   ( ${SRC_BASE}ecodms_${EDITION}32/wheezy/${MY_P}_i386.deb )
        "
SLOT="0"
KEYWORDS="~amd64 ~x86"
RESTRICT="mirror strip"
IUSE="english bundled-qt5"

QA_PREBUILT="*"

DEPEND=""

RDEPEND="${DEPEND}
        !bundled-qt5? ( dev-qt/qtwebkit:5 )
        !bundled-qt5? ( dev-qt/qtxml:5 )
        !bundled-qt5? ( dev-qt/qtwidgets:5 )
        !bundled-qt5? ( dev-qt/qtsvg:5 )
        !bundled-qt5? ( dev-qt/qtgui:5[evdev] )
        !bundled-qt5? ( dev-qt/qtcore:5[icu] )
        !bundled-qt5? ( dev-qt/qtopengl:5 )
        !bundled-qt5? ( dev-qt/qtsql:5 )
        !bundled-qt5? ( dev-qt/qtprintsupport:5 )
        !bundled-qt5? ( dev-qt/qtx11extras:5 )
        !bundled-qt5? ( dev-qt/qtdbus:5 )
        !bundled-qt5? ( dev-qt/qtnetwork:5 )
        !bundled-qt5? ( dev-qt/qthelp:5 )
        !bundled-qt5? ( dev-qt/qtsensors:5 )
        !bundled-qt5? ( dev-qt/qtconcurrent:5 )
        !bundled-qt5? ( dev-qt/qtpositioning:5[geoclue] )
        !bundled-qt5? ( dev-qt/qtmultimedia:5 )
        !bundled-qt5? ( dev-qt/qtimageformats:5 )

        dev-libs/libappindicator
        dev-libs/libpcre
        media-libs/freeimage
        media-libs/jpeg:8
        media-libs/libpng:1.2
        media-libs/tiff:3
        media-libs/opencv
        media-libs/libdmtx
        dev-libs/icu
        media-libs/tiff"

#        !bundled-qt5? ( dev-qt/qtquick1:5 )
#        !bundled-qt5? ( dev-qt/qtscript:5 )
#        !bundled-qt5? ( dev-qt/qtxmlpatterns:5 )
#        !bundled-qt5? ( dev-qt/qttest:5 )
#        !bundled-qt5? ( dev-qt/qtdeclarative:5 )

S=${WORKDIR}

src_prepare() {
    rm ${S}/_gpgbuilder
    rm ${S}/opt/ecodms/ecodmsclient/platformthemes/libqgtk2.so
    rm ${S}/opt/ecodms/ecodmsclient/update-unity.sh
}

src_install() {
    INSHOME=${S}/opt/ecodms/ecodmsclient
    ECOHOME=/opt/ecodms/ecodmsclient

    dosym /usr/$(get_libdir)/libappindicator3.so ${ECOHOME}/libappindicator.so.1
    dosym /usr/$(get_libdir)/libpcreposix.so ${ECOHOME}/libpcre.so.3

    use english && cp ${INSHOME}/language_en.qm ${INSHOME}/language.qm
	use english || cp ${INSHOME}/language_de.qm ${INSHOME}/language.qm

    # if the bundled Qt5 should be used, just install everything
    # it is no problem if some files will be overwritten later :)
    if use bundled-qt5; then
      doins -r opt
    fi

    insinto ${ECOHOME}
    exeinto ${ECOHOME}
    for i in PDFA_def.ps eciRGB_v2.icc ecodmssteppdfconvert.ini header.ps language.qm language_en.qm language_de.qm; do
      doins opt/ecodms/ecodmsclient/$i
    done;
    for i in advert advert3 icons tessdata plugins; do
      doins -r opt/ecodms/ecodmsclient/$i
    done;
    for i in libecodmsclassifyplugin.so libclassifyclient.so libecoactivemqclient.so libecoarchiveclient.so; do
      doexe opt/ecodms/ecodmsclient/$i
    done
    for i in pdfoverlay printcomworker ecodmssinglesignon ecodmsprinthandler ecodmsclient createpdfa.sh splitpdf.sh; do
      doexe opt/ecodms/ecodmsclient/$i
    done
    doexe ${FILESDIR}/ecodmsclient.sh ${FILESDIR}/ecodmsconmgr.sh

    make_desktop_entry ${ECOHOME}/ecodmsconmgr.sh "ecoDMS Connection Manager" ${ECOHOME}/icons/signon.png Office "Path=${ECOHOME}\nStartupNotify=true"
    make_desktop_entry ${ECOHOME}/ecodmsclient.sh "ecoDMS Client" ${ECOHOME}/icons/ecodms.png Office "Path=${ECOHOME}\nStartupNotify=true"
}

#pkg_preinst() {
#}

pkg_postinst() {
    fdo-mime_desktop_database_update
    fdo-mime_mime_database_update
    gnome2_icon_cache_update
	optfeature "PDF/A printer" net-print/ecodmsprinter
	optfeature "ecoICE Image Correction Editor" app-office/ecoice
    elog "Notice: If the Profile Manager's icon does not appear in the systray"
    elog "try switching off an active compositor. This seems to be a bug in Qt."
}

#pkg_postrm() {
#}

